Utils
=====

Many Things
-----------
.. automodule:: ls.joyous.utils.manythings
    :members:

Mix-ins
-------
.. automodule:: ls.joyous.utils.mixins
    :members:

Names
-----
.. automodule:: ls.joyous.utils.names
    :members:

Recurrence
----------
.. automodule:: ls.joyous.utils.recurrence
    :members:

Tell time
---------
.. automodule:: ls.joyous.utils.telltime
    :members:

Weeks
-----
Sets "Monday" or "Sunday" as the first day of the week depending upon the
Django FIRST_DAY_OF_WEEK format.

.. automodule:: ls.joyous.utils.weeks
    :members:
    :no-private-members:

